==> django_tidings-1.1-py2.py3-none-any.whl: tidings/migrations/0001_initial.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('contenttypes', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Watch',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('event_type', models.CharField(max_length=30, db_index=True)),
                ('object_id', models.PositiveIntegerField(null=True, db_index=True)),
                ('email', models.EmailField(db_index=True, max_length=75, null=True, blank=True)),
                ('secret', models.CharField(max_length=10, null=True, blank=True)),
                ('is_active', models.BooleanField(default=False, db_index=True)),
                ('content_type', models.ForeignKey(blank=True, to='contenttypes.ContentType', null=True)),
                ('user', models.ForeignKey(blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='WatchFilter',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=20)),
                ('value', models.PositiveIntegerField()),
                ('watch', models.ForeignKey(related_name='filters', to='tidings.Watch')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.AlterUniqueTogether(
            name='watchfilter',
            unique_together=set([('name', 'watch')]),
        ),
    ]

==> django_tidings-2.0-py2.py3-none-any.whl: tidings/migrations/0001_initial.py <==
# -*- coding: utf-8 -*-
# flake8: noqa
from __future__ import unicode_literals

from django.db import models, migrations
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('contenttypes', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Watch',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('event_type', models.CharField(max_length=30, db_index=True)),
                ('object_id', models.PositiveIntegerField(null=True, db_index=True)),
                ('email', models.EmailField(db_index=True, max_length=75, null=True, blank=True)),
                ('secret', models.CharField(max_length=10, null=True, blank=True)),
                ('is_active', models.BooleanField(default=False, db_index=True)),
                ('content_type', models.ForeignKey(blank=True, to='contenttypes.ContentType', null=True, on_delete=models.CASCADE)),
                ('user', models.ForeignKey(blank=True, to=settings.AUTH_USER_MODEL, null=True, on_delete=models.CASCADE)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='WatchFilter',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=20)),
                ('value', models.PositiveIntegerField()),
                ('watch', models.ForeignKey(related_name='filters', to='tidings.Watch', on_delete=models.CASCADE)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.AlterUniqueTogether(
            name='watchfilter',
            unique_together=set([('name', 'watch')]),
        ),
    ]
